==> deepin-camera_1.0.0.15.orig.tar.xz: deepin-camera-1.0.0.15/src/translations/deepin-camera_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Registrazione in corso, terminarla?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Apri cartella</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>None</source>
        <translation>No</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Apri cartella</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Non hai le autorizzazioni per modificare questa cartella</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation>Cartella non valida</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Apri cartella</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Base</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Locazione file</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Scatta</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Scatto continuo</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Scatto ritardato</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Output</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Formato output</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pcs</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pcs</translation>
    </message>
    <message>
        <source>None</source>
        <translation>No</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Camera è un&apos;app di acquisizione immagini e video che sfrutta la camera integrata nel tuo dispositivo.
Localizzazione italiana a cura di Massimo A. Carofano.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>File non salvato</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Salva in: </translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto: </translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video: </translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Impostazioni risoluzione</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Risoluzione: </translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>Scatta foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Registra video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Interrompi scatti</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>No</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Nessuna camera rilevata</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Questa camera è in uso</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Interrompi video</translation>
    </message>
</context>
</TS>

==> deepin-camera_1.3.10.orig.tar.xz: deepin-camera-1.3.10/src/translations/deepin-camera_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Registrazione in corso, terminarla?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Apri cartella</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>None</source>
        <translation>No</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Cambia Camera</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Apri cartella</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Stampa</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Non hai le autorizzazioni per modificare questa cartella</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Cartella non valida</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Apri cartella</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Base</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Locazione file</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Scatta</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Scatto continuo</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Scatto ritardato</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Output</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Formato output</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 pcs</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 pcs</translation>
    </message>
    <message>
        <source>None</source>
        <translation>No</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Camera è un&apos;app di acquisizione immagini e video che sfrutta la camera integrata nel tuo dispositivo.
Localizzazione italiana a cura di Massimo A. Carofano.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>File non salvato</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Salva in: </translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto: </translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video: </translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Impostazioni risoluzione</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Risoluzione: </translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Effetti sonori</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Modalità specchio</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Interrompi video</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Stampa</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostra scorciatoie</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Interrompi scatti</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Menu contestuale</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Scatta foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Registra video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Interrompi scatti</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>No</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normale</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Vivido</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Caldo</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Freddo</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Griglio</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>Bianco e nero</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Attivo</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Disattivo</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Ritarda scatto</translation>
    </message>
    <message>
        <source>None</source>
        <translation>No</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtri</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Esposizione</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Nessuna camera rilevata</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Questa camera è in uso</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Interrompi video</translation>
    </message>
</context>
</TS>
